use askama::Template;
use chrono::{Days, NaiveDateTime};
use chrono::{NaiveDate, NaiveTime};
use serde::Deserialize;

use crate::filters;
use crate::models::{Location, Role, User};
use crate::utils::DateTimeFormat::{DayMonthYear, HourMinute, YearMonthDayTHourMinute};

pub mod delete;
pub mod get_edit;
pub mod get_new;
pub mod get_plan;
pub mod post_edit;
pub mod post_new;
pub mod put_cancelation;

#[derive(Template)]
#[cfg_attr(not(test), template(path = "events/new_or_edit.html"))]
#[cfg_attr(test, template(path = "events/new_or_edit.html", block = "content"))]
pub struct NewOrEditEventTemplate {
    user: User,
    date: NaiveDate,
    locations: Vec<Location>,
    id: Option<i32>,
    start: NaiveTime,
    end: NaiveDateTime,
    name: Option<String>,
    location: Option<i32>,
    voluntary_wachhabender: bool,
    voluntary_fuehrungsassistent: bool,
    amount_of_posten: Option<i16>,
    clothing: Option<i32>,
    canceled: bool,
    note: Option<String>,
    amount_of_planned_posten: usize,
    is_fuehrungsassistent_planned: bool,
    is_wachhabender_planned: bool,
}

#[derive(Deserialize)]
pub struct NewOrEditEventForm {
    name: String,
    date: NaiveDate,
    start: NaiveTime,
    #[serde(with = "short_date_time_format")]
    end: NaiveDateTime,
    location: i32,
    voluntarywachhabender: bool,
    voluntaryfuehrungsassistent: bool,
    amount: i16,
    clothing: i32,
    note: Option<String>,
}

mod short_date_time_format {
    use chrono::NaiveDateTime;
    use serde::{self, Deserialize, Deserializer};

    pub fn deserialize<'de, D>(deserializer: D) -> Result<NaiveDateTime, D::Error>
    where
        D: Deserializer<'de>,
    {
        const FORMAT: &'static str = "%Y-%m-%dT%H:%M";
        let s = String::deserialize(deserializer)?;
        let dt = NaiveDateTime::parse_from_str(&s, FORMAT).map_err(serde::de::Error::custom)?;
        Ok(dt)
    }
}
